@@ -10,7 +10,7 @@
 #' @param assignment_probs A numeric vector of length \code{k}. Independent probability of assignment to each treatment. 
 #' @param outcome_name A character. Name of outcome variable (defaults to "Y"). Must be provided without spacing inside the function \code{c()} as in \code{outcome_name = c("War")}.
 #' @param treatment_names A character vector of length \code{k}. Name of treatment factors variable (defaults to "T1", "T2", ..., "Tk"). Must be provided without spacing.
-#' @param fixed A character vector. Names of arguments to be fixed in design. By default \code{k}, \code{probs}, \code{outcome_name}, and \code{treatment_names} are always fixed.
+#' @param args_to_fix A character vector. Names of arguments to be args_to_fix in design. By default \code{k}, \code{probs}, \code{outcome_name}, and \code{treatment_names} are always args_to_fix.
 #' @return A factorial design.
 #' @details 
 #' 
@@ -85,9 +85,9 @@ factorial_designer <- function(
   sd = 1, 
   outcome_sds = rep(sd, 2^k),
   assignment_probs = rep(.5, k),
-  outcome_name = c("Y"),
+  outcome_name = "Y",
   treatment_names = NULL,
-  fixed = NULL
+  args_to_fix = NULL
 ){
   
   # tests -------------------------------------------------------------------
@@ -95,6 +95,7 @@ factorial_designer <- function(
   if(any(grepl(" ", fixed = TRUE, outcome_name))) stop("Please remove spaces from `outcome_name' strings.")
   if(length(outcome_means) != 2^k || length(outcome_sds) != 2^k) stop("`outcome_means' and `outcome_sds` arguments must be the same as length of 2^(k).")
   if(length(assignment_probs) != k) stop("`assignment_probs` must be the same as length of k.")
+  if(!is.null(treatment_names) && length(treatment_names) != k) stop("Length of `treatment_names` must be the same as length of k.")
   if(k < 2 || !is_integerish(k)) stop("`k' should be a positive integer > 1.")
   if(any(outcome_sds<0)) stop("`outcome_sds' should be nonnegative.")
   if(any(assignment_probs <= 0)) stop("`assignment_probs' should have positive values only.")
@@ -125,14 +126,14 @@ factorial_designer <- function(
   
   cond_row <- lapply(1:k, function(x) which(cond_grid[,x]==1))
   
-  # fixed argument ----------------------------------------------------------
+  # args_to_fix argument ----------------------------------------------------------
   
   outcome_sds_ <- outcome_sds; outcome_means_ <- outcome_means; assignment_probs_ <- assignment_probs; N_ <- N; k_ <- k 
   
-  if(is.null(fixed)) fixed <- ""
-  if(!"outcome_sds"   %in% fixed)  outcome_sds_ <- sapply(1:length(outcome_sds), function(i) expr(outcome_sds[!!i])) 
-  if(!"outcome_means" %in% fixed)  outcome_means_ <- sapply(1:length(outcome_means), function(i) expr(outcome_means[!!i])) 
-  if(!"N" %in% fixed)  N_ <- expr(N)
+  if(is.null(args_to_fix)) args_to_fix <- ""
+  if(!"outcome_sds"   %in% args_to_fix)  outcome_sds_ <- sapply(1:length(outcome_sds), function(i) expr(outcome_sds[!!i])) 
+  if(!"outcome_means" %in% args_to_fix)  outcome_means_ <- sapply(1:length(outcome_means), function(i) expr(outcome_means[!!i])) 
+  if(!"N" %in% args_to_fix)  N_ <- expr(N)
   
   
   # population --------------------------------------------------------------
@@ -251,23 +252,12 @@ factorial_designer <- function(
                                        match.call.defaults(),
                                        # rlang = TRUE,
                                        arguments_as_values = TRUE,
-                                       exclude_args = c("k", "assignment_probs", "outcome_name", "treatment_names", "sd", fixed, "fixed"))
+                                       exclude_args = c("k", "assignment_probs", "outcome_name", "treatment_names", "sd", args_to_fix, "args_to_fix"))
   
   
-  design_code <-
-    gsub("eval_bare\\(population_expr\\)", quo_text(population_expr), design_code)
-  design_code <-
-    gsub("eval_bare\\(potential_outcomes_expr\\)", quo_text(potential_outcomes_expr), design_code)
-  design_code <-
-    gsub("eval_bare\\(reveal_expr\\)", quo_text(reveal_expr), design_code)
-  design_code <-
-    gsub("eval_bare\\(estimand_expr\\)", quo_text(estimand_expr), design_code)
-  design_code <- 
-    gsub("eval_bare\\(assignment_expr1\\)", quo_text(assignment_expr1), design_code)
-  design_code <- 
-    gsub("eval_bare\\(assignment_expr2\\)", quo_text(assignment_expr2), design_code)
-  design_code <- 
-    gsub("eval_bare\\(estimator_expr\\)", quo_text(estimator_expr), design_code)
+  design_code <- sub_expr_text(design_code, population_expr, potential_outcomes_expr,
+                               reveal_expr, estimand_expr, assignment_expr1, 
+                               assignment_expr2, estimator_expr)
   
   attr(factorial_design, "code") <- design_code
   
@@ -275,17 +265,34 @@ factorial_designer <- function(
   
 }
 
+attr(factorial_designer,"definitions") <- data.frame(
+  names         = c("N", "k", "outcome_means", "sd", "outcome_sds", 
+                    "assignment_probs", "outcome_name", "treatment_names",
+                    "args_to_fix"),
+  tips          = c("Size of sample",
+                    "The number of factors in the design",
+                    "Means for each of the treatment combinations",
+                    "Standard deviation for outcomes",
+                    "Standard deviations for each of the treatment combinations",
+                    "Independent probability of assignment to each treatment",
+                    "Name of outcome variable",
+                    "Name of treatment factors variable",
+                    "Names of arguments to be args_to_fix"),
+  class         = c("integer", "integer", rep("numeric", 4), rep("character", 3)),
+  vector = c(FALSE, FALSE, TRUE, FALSE, TRUE, TRUE, FALSE, TRUE, TRUE),
+  min           = c(2, 2, -Inf, rep(0, 3), rep(NA, 3)),
+  max           = c(rep(Inf, 5), 1, rep(NA, 3)),
+  inspector_min = c(100, 2, 0, 0, 0, 0.1, NA, NA, NA),
+  inspector_step= c(100, 1, rep(.2, 4), rep(NA, 3)),
+  stringsAsFactors = FALSE
+)
+
 attr(factorial_designer,"shiny_arguments") <-
   list(
     N = c(50, 100, 500, 1000),
     k = c(2, 3, 4)
   )
 
-attr(factorial_designer,"tips") <-
-  c(N = "Size of sample",
-    k = "The number of factors in the design"
-  )
-
 attr(factorial_designer,"description") <- "
 <p> A <code>2^k</code> factorial designer with <code>k</code> factors assigned with independent
 probabilities. Results in <code>2^k</code> treatment combinations, each with independent,
