@@ -12,6 +12,7 @@
 #' @param control_coefs A vector of numbers. Coefficients for polynomial regression function that generates control potential outcomes. Order of polynomial is equal to length.
 #' @param treatment_coefs A vector of numbers. Coefficients for polynomial regression function that generates treatment potential outcomes. Order of polynomial is equal to length.
 #' @param poly_reg_order Integer greater than or equal to 1. Order of the polynomial regression used to estimate the jump at the cutoff.
+#' @param args_to_fix A character vector. Names of arguments to be args_to_fix in design.
 #' @return A regression discontinuity design.
 #' @author \href{https://declaredesign.org/}{DeclareDesign Team}
 #' @concept observational
@@ -35,7 +36,8 @@ regression_discontinuity_designer <- function(
   bandwidth = .5,
   control_coefs = c(.5,.5),
   treatment_coefs = c(-5,1),
-  poly_reg_order = 4
+  poly_reg_order = 4,
+  args_to_fix = NULL
 ){
   if(cutoff <= 0 || cutoff >= 1) stop("cutoff must be in (0,1).")
   if(poly_reg_order < 1) stop("poly_reg_order must be at least 1.")
@@ -47,16 +49,20 @@ regression_discontinuity_designer <- function(
     # M: Model
     control <- function(X) {
       as.vector(poly(X, length(control_coefs), raw = T) %*% control_coefs)}
+    
     treatment <- function(X) {
       as.vector(poly(X, length(treatment_coefs), raw = T) %*% treatment_coefs) + tau}
+    
     population <- declare_population(
       N = N,
       X = runif(N,0,1) - cutoff,
       noise = rnorm(N,0,outcome_sd),
       Z = 1 * (X > 0))
+    
     potential_outcomes <- declare_potential_outcomes(
       Y_Z_0 = control(X) + noise,
       Y_Z_1 = treatment(X) + noise)
+    
     reveal_Y <- declare_reveal(Y)
     
     # I: Inquiry
@@ -84,6 +90,27 @@ regression_discontinuity_designer <- function(
   regression_discontinuity_design
 }
 
+attr(regression_discontinuity_designer, "definitions") <- data.frame(
+  names = c("N","tau","outcome_sd","cutoff","bandwidth","control_coefs",
+            "treatment_coefs","poly_reg_order","args_to_fix"),
+  tips  = c("Size of population to sample from",
+            "Difference in potential outcomes functions at the threshold",
+            "Standard deviation of the outcome",
+            "Threshold on running variable beyond which units are treated",
+            "Bandwidth around threshold from which to include units",
+            "Coefficients for polynomial regression function that generates control potential outcomes",
+            "Coefficients for polynomial regression function that generates treatment potential outcomes",
+            "Order of the polynomial regression used to estimate the jump at the cutoff",
+            "Names of arguments to be args_to_fix"),
+  class = c("integer", rep("numeric", 6), "integer","character"), 
+  vector = c(rep(FALSE, 5), TRUE, TRUE, FALSE, TRUE),
+  min = c(2, -Inf, 0, 0, rep(-Inf, 3), 1, NA),
+  max = c(Inf, Inf, Inf, 1, Inf, Inf, Inf, 10, NA),
+  inspector_min = c(100, 0, 0, 0.1, .1, 0, 0, 1, NA),
+  inspector_step = c(50, rep(.2, 6), 1, NA),
+  stringsAsFactors = FALSE
+)
+
 attr(regression_discontinuity_designer,"shiny_arguments") <-
   list(
     N = c(1000, 50,100, 10000),
@@ -93,14 +120,6 @@ attr(regression_discontinuity_designer,"shiny_arguments") <-
     poly_reg_order = c(4, 3, 2, 1)
   )
 
-attr(regression_discontinuity_designer,"tips") <-
-  c(N = "Size of population to sample from",
-    tau = "Difference in potential outcomes functions at the threshold",
-    cutoff = "Threshold on running variable beyond which units are treated",
-    bandwidth = "Bandwidth around threshold from which to include units",
-    poly_reg_order = "Order of the polynomial regression used to estimate the jump at the cutoff"
-  )
-
 attr(regression_discontinuity_designer,"description") <- "
 <p> A regression discontinuity design with sample from population of size <code>N</code>. 
     The average treatment effect local to the cutpoint is equal to <code>tau</code>. 
